Function to call connectome with databases from OmniPath [[DEPRECATED]]
Source:R/connectome_pipe.R
call_connectome.RdFunction to call connectome with databases from OmniPath [[DEPRECATED]]
Details
Stats: 1) The ‘weight_norm’ edge attribute is derived from the normalized expression of the ligand and the receptor in the single-cell data. 2) The ‘weight_scale’ edge attribute is derived from the z-scores of the ligand and the receptor in each edge, and is of higher value when the ligand and receptor are more specific to a given pair of cell types 3) DEG p-values for L and R