Helper Function which returns the mean, unless there is a 0 value then it returns 0
Source:R/liana_recomplexify.R
mean0.RdHelper Function which returns the mean, unless there is a 0 value then it returns 0
R/liana_recomplexify.R
mean0.RdHelper Function which returns the mean, unless there is a 0 value then it returns 0